#########################################################################
#
#  URLS for Inventory Data
########################################################################
# ghcnd-countries.txt
# ghcnd-inventory.txt
# ghcnd-stations.txt
#
GHCN.DAILY.COUNTRY.URL   <- "ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/ghcnd-countries.txt"
GHCN.DAILY.INVENTORY.URL <- "ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/ghcnd-inventory.txt"
GHCN.DAILY.METADATA.URL  <- "ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/ghcnd-stations.txt"
GHCN.DAILY.DATA.URL      <- "ftp://ftp.ncdc.noaa.gov/pub/data/ghcn/daily/all/"
DAILY.DATA.DIRECTORY     <- "DailyRaw"
MONTHLY.DATA.DIRECTORY   <- "MonthlyData"
DAILY.FILES.DIRECTORY    <- "DailyFiles"
DAILY.QA.DIRECTORY       <- "DailyData"